@@ -23,7 +23,9 @@
 #ifndef MODUTILS_UTIL_H
 #define MODUTILS_UTIL_H 1
 
-#ident "$Id: util.h 1.5 Tue, 25 Jul 2000 11:43:00 +1000 kaos $"
+#ident "$Id: util.h 1.6 Sun, 06 Aug 2000 08:20:16 -0700 kaos $"
+
+#include <sys/stat.h>
 
 #define SHELL_META "&();|<>$`\"'\\!{}[]~=+:?*" /* Sum of bj0rn and Debian */
 
@@ -32,11 +34,17 @@ void *xrealloc(void *, size_t);
 char *xstrdup(const char *);
 int   arch64(void);
 
+typedef int (*xftw_func_t)(const char *, const struct stat *);
+extern int xftw(const char *directory, xftw_func_t);
+
 /* Error logging */
 extern int log;
 extern int errors;
 extern const char *error_file;
 
+extern int flag_verbose;
+extern void verbose(const char *ctl,...);
+
 void error(const char *fmt, ...)
 #ifdef __GNUC__
   __attribute__((format(printf, 1, 2)))
