@@ -48,7 +48,7 @@
        Keith Owens <kaos@ocs.com.au> April 2000.
    */
 
-#ident "$Id: insmod.c 1.24 Mon, 07 Aug 2000 18:07:12 +1000 kaos $"
+#ident "$Id: insmod.c 1.25 Sun, 13 Aug 2000 06:45:56 -0700 kaos $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -1315,7 +1315,7 @@ int INSMOD_MAIN(int argc, char **argv)
 			flag_ksymoops = 1;
 			break;
 		case 'r':	/* allow root to load non-root modules */
-			root_check_off = 1;
+			root_check_off = !root_check_off;
 			break;
 		case 'P':	/* use prefix on crc */
 			set_ncv_prefix(optarg);
