@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: sys_nim.c 1.1 Wed, 25 Aug 1999 16:26:49 +1000 keith $"
+#ident "$Id: sys_nim.c 1.3 Sat, 08 Jul 2000 22:44:35 -0700 kaos $"
 
 #include <stdlib.h>
 #include <errno.h>
@@ -34,6 +34,20 @@
 
 /*======================================================================*/
 
+#ifndef CONFIG_USE_SYSCALL
+
+extern int init_module(const char *name, const struct module *info);
+
+int 
+sys_init_module(const char *name, const struct module *info)
+{
+  return init_module(name, info);
+}
+
+#else
+
 #define __NR_sys_init_module  __NR_init_module
 _syscall2(int, sys_init_module, const char *, name,
 	  const struct module *, info)
+
+#endif
