@@ -1,5 +1,5 @@
 /* Functions for the Linux module syscall interface.
-   Copyright 1996 Free Software Foundation, Inc.
+   Copyright 1996, 1997 Linux International.
    Contributed by Richard Henderson <rth@tamu.edu>
 
    This file is part of the Linux modutils.
@@ -18,6 +18,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#ident "$Id: sys_qm.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 #include <stdlib.h>
 #include <errno.h>
@@ -35,8 +36,20 @@
 
 /* I am fucking tired of the "this doesn't build on 2.0.x" questions.
    But if you ask, we still officially require 2.1.x to build.  */
-#if !defined(__NR_query_module) && defined(__i386__)
-# define __NR_query_module 167
+#if !defined(__NR_query_module)
+# if defined(__i386__)
+#  define __NR_query_module 167
+# elif defined(__alpha__)
+#  define __NR_query_module 347
+# elif defined(__sparc__)
+#  define __NR_query_module 184
+# elif defined(__mc68000__)
+#  define __NR_query_module 167
+# elif defined(__arm__)
+#  define __NR_query_module (__NR_SYSCALL_BASE + 167)
+# elif defined(__mips__)
+#  define __NR_query_module 4187
+# endif
 #endif
 
 _syscall5(int, query_module, const char *, name, int, which,
